print_ClussCluster_Gap: Prints out the results of ClussCluster_Gap
Prints the gap statistics and number of genes selected for each candidate tuning parameter.
Description
Prints out the results of ClussCluster_Gap
Prints the gap statistics and number of genes selected for each candidate tuning parameter.
Usage
print_ClussCluster_Gap(object)
Arguments
object
An object that is obtained by applying the ClussCluster_Gap function to the data set.